@@ -17,45 +17,25 @@ expect_lint <- function(content, checks, ..., file = NULL) {
     content <- readChar(file, file.info(file)$size)
   }
 
-    results <- expectation_lint(content, checks, ...)
-
-  reporter <- testthat::get_reporter()
-
-  # flatten list if a list of lists
-  if (is.list(results) &&
-    is.list(results[[1]]) &&
-    !testthat::is.expectation(results[[1]])) {
-
-    results <- unlist(recursive = FALSE, results)
-  }
-
-  if (testthat::is.expectation(results)) {
-    reporter$add_result(results)
-  }
-  else {
-    lapply(results, reporter$add_result)
-  }
-
-  invisible(results)
+  expectation_lint(content, checks, ...)
 }
 
 expectation_lint <- function(content, checks, ...) {
 
   filename <- tempfile()
   on.exit(unlink(filename))
-  cat(file=filename, content, sep="\n")
+  cat(file = filename, content, sep = "\n")
 
   lints <- lint(filename, ...)
 
   linter_names <- substitute(alist(...))[-1]
 
   if (is.null(checks)) {
-    return(testthat::expectation(length(lints) %==% 0L,
-        paste0(paste(collapse=", ", linter_names),
+    return(testthat::expect(length(lints) %==% 0L,
+        paste0(paste(collapse = ", ", linter_names),
           " returned ", print(lints),
           " lints when it was expected to return none!"),
-        paste0(paste(collapse=", ", linter_names),
-          " returned 0 lints as expected.")))
+        ))
   }
 
   if (!is.list(checks)) {
@@ -64,8 +44,8 @@ expectation_lint <- function(content, checks, ...) {
   checks[] <- lapply(checks, fix_names, "message")
 
   if (length(lints) != length(checks)) {
-    return(testthat::expectation(FALSE,
-        paste0(paste(collapse=", ", linter_names),
+    return(testthat::expect(FALSE,
+        paste0(paste(collapse = ", ", linter_names),
           " did not return ", length(checks),
           " lints as expected from content:", content, lints)))
   }
@@ -77,35 +57,19 @@ expectation_lint <- function(content, checks, ...) {
       value <- lint[[field]]
       check <- check[[field]]
       if (field == "message") {
-        testthat::expectation(re_matches(value, check),
+        testthat::expect(re_matches(value, check),
           sprintf("lint: %d %s: %s did not match: %s",
             itr,
             field,
             value,
-            check
-          ),
-          sprintf("lint: %d %s: %s matched: %s",
-            itr,
-            field,
-            value,
-            check
-          )
-        )
+            check))
       } else {
-        testthat::expectation(`==`(value, check),
+        testthat::expect(`==`(value, check),
           sprintf("lint: %d %s: %s did not match: %s",
             itr,
             field,
             value,
-            check
-          ),
-          sprintf("lint: %d %s: %s matched: %s",
-            itr,
-            field,
-            value,
-            check
-          )
-        )
+            check))
       }
     })
   },
@@ -115,11 +79,11 @@ expectation_lint <- function(content, checks, ...) {
 }
 
 #' Test that the package is lint free
-#' 
-#' This function is a thin wrapper around lint_package that simply tests there are no 
-#' lints in the package.  It can be used to ensure that your tests fail if the package 
+#'
+#' This function is a thin wrapper around lint_package that simply tests there are no
+#' lints in the package.  It can be used to ensure that your tests fail if the package
 #' contains lints.
-#' 
+#'
 #' @param ... arguments passed to \code{\link{lint_package}}
 #' @export
 expect_lint_free <- function(...) {
@@ -130,12 +94,10 @@ expect_lint_free <- function(...) {
   if (has_lints) {
     lint_output <- paste(collapse = "\n", capture.output(print(lints)))
   }
-  result <- testthat::expectation(!has_lints,
+  result <- testthat::expect(!has_lints,
                         paste(sep = "\n",
                               "Not lint free",
-                              lint_output),
-                        "lint free")
+                              lint_output))
 
-  testthat::get_reporter()$add_result(result)
   invisible(result)
 }
